pub struct BucketPlan {
pub name: String,
pub region: Option<String>,
pub path: Option<String>,
pub hmac_access_key: Option<String>,
pub hmac_secret: Option<String>,
}Fields
name: StringThis is the name of the bucket.
region: Option<String>This is the region of the bucket. Usage: - If credential.type is aws, then this is required. - If credential.type is gcp, then this is optional since GCP allows buckets to be accessed without a region but region is required for data residency requirements. Read here: https://cloud.google.com/storage/docs/request-endpoints This overrides the credential.region field if it is provided.
path: Option<String>This is the path where call artifacts will be stored. Usage: - To store call artifacts in a specific folder, set this to the full path. Eg. "/folder-name1/folder-name2". - To store call artifacts in the root of the bucket, leave this blank. @default "/"
hmac_access_key: Option<String>This is the HMAC access key offered by GCP for interoperability with S3 clients. Here is the guide on how to create: https://cloud.google.com/storage/docs/authentication/managing-hmackeys#console Usage: - If credential.type is gcp, then this is required. - If credential.type is aws, then this is not required since credential.awsAccessKeyId is used instead.
hmac_secret: Option<String>This is the secret for the HMAC access key. Here is the guide on how to create: https://cloud.google.com/storage/docs/authentication/managing-hmackeys#console Usage: - If credential.type is gcp, then this is required. - If credential.type is aws, then this is not required since credential.awsSecretAccessKey is used instead. Note: This is not returned in the API.
Implementations
Sourceimpl BucketPlan
impl BucketPlan
pub fn new(name: String) -> BucketPlan