Module client_message_workflow_node_started_phone_number

Module client_message_workflow_node_started_phone_number 

Enums

ClientMessageWorkflowNodeStartedPhoneNumber
ClientMessageWorkflowNodeStartedPhoneNumber : This is the phone number that the message is associated with. This is the phone number that the message is associated with.
ProviderTrue
This is to use numbers bought on Telnyx.