pub struct CreateVapiPhoneNumberDto {
pub fallback_destination: Option<ImportTwilioPhoneNumberDtoFallbackDestination>,
pub hooks: Option<Vec<ImportTwilioPhoneNumberDtoHooksInner>>,
pub provider: ProviderTrue,
pub number_desired_area_code: Option<String>,
pub sip_uri: Option<String>,
pub authentication: Option<SipAuthentication>,
pub name: Option<String>,
pub assistant_id: Option<String>,
pub workflow_id: Option<String>,
pub squad_id: Option<String>,
pub server: Option<Server>,
}Fields
fallback_destination: Option<ImportTwilioPhoneNumberDtoFallbackDestination>hooks: Option<Vec<ImportTwilioPhoneNumberDtoHooksInner>>This is the hooks that will be used for incoming calls to this phone number.
provider: ProviderTrueThis is to create free SIP phone numbers on Vapi.
number_desired_area_code: Option<String>This is the area code of the phone number to purchase.
sip_uri: Option<String>This is the SIP URI of the phone number. You can SIP INVITE this. The assistant attached to this number will answer. This is case-insensitive.
authentication: Option<SipAuthentication>This enables authentication for incoming SIP INVITE requests to the sipUri. If not set, any username/password to the 401 challenge of the SIP INVITE will be accepted.
name: Option<String>This is the name of the phone number. This is just for your own reference.
assistant_id: Option<String>This is the assistant that will be used for incoming calls to this phone number. If neither assistantId, squadId nor workflowId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.
workflow_id: Option<String>This is the workflow that will be used for incoming calls to this phone number. If neither assistantId, squadId, nor workflowId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.
squad_id: Option<String>This is the squad that will be used for incoming calls to this phone number. If neither assistantId, squadId, nor workflowId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.
server: Option<Server>This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is: 1. assistant.server 2. phoneNumber.server 3. org.server
Implementations
Sourceimpl CreateVapiPhoneNumberDto
impl CreateVapiPhoneNumberDto
pub fn new(provider: ProviderTrue) -> CreateVapiPhoneNumberDto