Struct KnowledgeBaseCost

pub struct KnowledgeBaseCost {
    pub cost: f64,
    pub cost_type: Type,
    pub model: Option<KnowledgeBaseModel>,
    pub promptTokens: Option<u32>,
    pub completionTokens: Option<u32>,
}
Example knowledge-base cost struct to match JSON like: { “cost”: 0, “type”: “knowledge-base”, “model”: { “model”: “gemini-1.5-flash”, “provider”: “google” }, “promptTokens”: 0, “completionTokens”: 0 }

Fields

cost: f64

This is the cost in USD.

cost_type: Type

The cost type (always “knowledge-base” for this struct).

model: Option<KnowledgeBaseModel>

The model used for knowledge-base lookups.

promptTokens: Option<u32>

The number of tokens in the prompt, if applicable.

completionTokens: Option<u32>

The number of tokens in the completion, if applicable.