pub struct ServerMessageEndOfCallReport {Show 14 fields
pub phone_number: Option<ClientMessageWorkflowNodeStartedPhoneNumber>,
pub type: TypeTrue,
pub ended_reason: EndedReasonTrue,
pub cost: Option<f64>,
pub costs: Option<Vec<CallCostsInner>>,
pub timestamp: Option<f64>,
pub artifact: Artifact,
pub assistant: Option<CreateAssistantDto>,
pub customer: Option<CreateCustomerDto>,
pub call: Option<Call>,
pub chat: Option<Chat>,
pub analysis: Analysis,
pub started_at: Option<String>,
pub ended_at: Option<String>,
}Fields
phone_number: Option<ClientMessageWorkflowNodeStartedPhoneNumber>type: TypeTrueThis is the type of the message. "end-of-call-report" is sent when the call ends and post-processing is complete.
ended_reason: EndedReasonTrueThis is the reason the call ended. This can also be found at call.endedReason on GET /call/:id.
cost: Option<f64>This is the cost of the call in USD. This can also be found at call.cost on GET /call/:id.
costs: Option<Vec<CallCostsInner>>These are the costs of individual components of the call in USD. This can also be found at call.costs on GET /call/:id.
timestamp: Option<f64>This is the timestamp of the message.
artifact: ArtifactThese are the artifacts from the call. This can also be found at call.artifact on GET /call/:id.
assistant: Option<CreateAssistantDto>This is the assistant that the message is associated with.
customer: Option<CreateCustomerDto>This is the customer that the message is associated with.
call: Option<Call>This is the call that the message is associated with.
chat: Option<Chat>This is the chat object.
analysis: AnalysisThis is the analysis of the call. This can also be found at call.analysis on GET /call/:id.
started_at: Option<String>This is the ISO 8601 date-time string of when the call started. This can also be found at call.startedAt on GET /call/:id.
ended_at: Option<String>This is the ISO 8601 date-time string of when the call ended. This can also be found at call.endedAt on GET /call/:id.
Implementations
Sourceimpl ServerMessageEndOfCallReport
impl ServerMessageEndOfCallReport
pub fn new( type: TypeTrue, ended_reason: EndedReasonTrue, artifact: Artifact, analysis: Analysis, ) -> ServerMessageEndOfCallReport