pub struct TextEditorTool {
pub messages: Option<Vec<CreateDtmfToolDtoMessagesInner>>,
pub type: TypeTrue,
pub sub_type: SubTypeTrue,
pub server: Option<Server>,
pub id: String,
pub org_id: String,
pub created_at: String,
pub updated_at: String,
pub function: Option<OpenAiFunction>,
pub name: NameTrue,
}Fields
messages: Option<Vec<CreateDtmfToolDtoMessagesInner>>These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.
type: TypeTrueThe type of tool. "textEditor" for Text Editor tool.
sub_type: SubTypeTrueThe sub type of tool.
server: Option<Server>This is the server where a tool-calls webhook will be sent. Notes: - Webhook is sent to this server when a tool call is made. - Webhook contains the call, assistant, and phone number objects. - Webhook contains the variables set on the assistant. - Webhook is sent to the first available URL in this order: {{tool.server.url}}, {{assistant.server.url}}, {{phoneNumber.server.url}}, {{org.server.url}}. - Webhook expects a response with tool call result.
id: StringThis is the unique identifier for the tool.
org_id: StringThis is the unique identifier for the organization that this tool belongs to.
created_at: StringThis is the ISO 8601 date-time string of when the tool was created.
updated_at: StringThis is the ISO 8601 date-time string of when the tool was last updated.
function: Option<OpenAiFunction>This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument "reason". Then, in messages array, you can have many "request-complete" messages. One of these messages will be triggered if the messages[].conditions matches the "reason" argument.
name: NameTrueThe name of the tool, fixed to ‘str_replace_editor’
Implementations
Sourceimpl TextEditorTool
impl TextEditorTool
pub fn new( type: TypeTrue, sub_type: SubTypeTrue, id: String, org_id: String, created_at: String, updated_at: String, name: NameTrue, ) -> TextEditorTool