Enums
- Client
Message Workflow Node Started Phone Number - ClientMessageWorkflowNodeStartedPhoneNumber : This is the phone number that the message is associated with. This is the phone number that the message is associated with.
- Provider
True - This is to use numbers bought on Telnyx.